pub enum Flow {
Auto,
AuthCode,
Device,
}Variants
Auto
The device flow where the provider offers one, the browser flow otherwise. Microsoft’s built-in client cannot serve a loopback redirect, so for it this is the only flow that works.
AuthCode
Device